"use strict";
///<reference path="../typings/index.d.ts" />
var test = require('tape');
var EscapeStack_1 = require('./EscapeStack');
var NUM_TIMES = 5;
function addToStack(escapeStack, t, numTimes) {
    if (numTimes === void 0) { numTimes = 1; }
    for (var i = 0; i < numTimes; i++) {
        escapeStack.add(function () { return t.pass(); });
    }
}
function popOffStack(escapeStack, numTimes) {
    if (numTimes === void 0) { numTimes = 1; }
    for (var i = 0; i < numTimes; i++) {
        escapeStack.pop();
    }
}
test("it should call the handler's callback when popped", function (t) {
    t.plan(1);
    var es = new EscapeStack_1.EscapeStack();
    es.add(function () { return t.pass(); });
    es.pop();
});
test("it should call every handler's callback when popped", function (t) {
    t.plan(NUM_TIMES);
    var es = new EscapeStack_1.EscapeStack();
    addToStack(es, t, NUM_TIMES);
    popOffStack(es, NUM_TIMES);
});
test("it should not call any callbacks when popping an empty stack", function (t) {
    t.plan(NUM_TIMES);
    var es = new EscapeStack_1.EscapeStack();
    addToStack(es, t, NUM_TIMES);
    popOffStack(es, NUM_TIMES);
    // stack should be empty now, popping should not have any effect
    popOffStack(es, NUM_TIMES);
});
test("it should remove handlers in the stack without calling their callbacks", function (t) {
    t.plan(NUM_TIMES * 2);
    var es = new EscapeStack_1.EscapeStack();
    addToStack(es, t, NUM_TIMES);
    // add a handler that will be removed into the middle of the stack
    var removeHandler = es.add(function () { return t.pass(); });
    addToStack(es, t, NUM_TIMES);
    // this should not call its callback
    removeHandler();
    // despite pop being called the total number of handlers times,
    // it should not execute the handlers that were removed
    popOffStack(es, NUM_TIMES + 1);
});
//# sourceMappingURL=test.spec.js.map